from window_ui import register


def start_up_window():
    """
    :return:
    """
    register()